@@ -1,11 +1,12 @@
 #!/usr/bin/perl
 
-use strict;
+use v5.26;
 use warnings;
 
 use Device::Chip::LTC2400;
 use Device::Chip::Adapter;
 
+use Future::AsyncAwait;
 use Getopt::Long;
 
 GetOptions(
@@ -14,17 +15,17 @@ GetOptions(
 ) or exit 1;
 
 my $chip = Device::Chip::LTC2400->new;
-$chip->mount_from_paramstr(
+await $chip->mount_from_paramstr(
    Device::Chip::Adapter->new_from_description( $ADAPTER ),
    $MOUNTPARAMS,
-)->get;
+);
 
-$chip->protocol->power(1)->get;
+await $chip->protocol->power(1);
 
 my $RANGE = 4.096;
 
 while(1) {
-   my $reading = $chip->read_adc->get;
+   my $reading = await $chip->read_adc;
 
    my $value = $reading->{VALUE};
    $value += 2 ** 24 if $reading->{EXR};
